#!/usr/bin/perl -w
use strict;
use warnings;

package cnfFile;

# -> constructor
# my $myCnf=cnfFile->new(fileName => 'cnfFile.cnf'); 
#
sub new {
    my $class=shift;
    my $self={@_};
    $self->{CNF}=();
    bless($self,$class);
    return $self;
}

# -> get fileName
# print $myCnf->get()."\n"; 
# -> get SectionA.Value
# print $myCnf->get('SectionA.Value')."\n"; 
#
sub get {
    my $self=shift;
    my $name= (@_) ? shift : '';
    return ($name ne '') ? $self->{CNF}->{$name} : $self->{fileName};
}

# -> read the hash {CNF} from fileName
# $myCnf->read();
#
sub read {
    my $self=shift;
    my $file;
    my $section='';
    if (-e $self->{fileName}) {
        open $file,$self->{fileName};
        if ($file) {
            my ($line,$char);
            while ($line=<$file>) {
                chomp($line);
                $char=substr($line,0,1);
                if ($char eq ':') {
                    $section=substr($line,1);
                }
                elsif ($char ne '#') {
                    my @fields=split(/=/,$line,2);
                    $self->{CNF}->{$section.'.'.$fields[0]}=$fields[1];
                    # print "'$section.$fields[0]' -> $fields[1]\n";
                }
            }
        }
    }
}

# -> write the hash {CNF} to fileName
# $myCnf->write();
#
sub write {
    my $self=shift;
    my %hsh=%{$self->{CNF}};
    my ($key,$file);
    my $section='';
    open $file,">$self->{fileName}";
    if ($file) {    
        foreach $key (sort(keys(%hsh))) {
            my @fields=split(/\./,$key,2);
            if ($fields[0] ne $section) {
                $section=$fields[0];
                print $file ':'.$section."\n";
            }
            print $file "$fields[1]=$hsh{$key}\n";
        }
        close($file);
    }
}

# -> set fileName
# print $myCnf->get()."\n"; 
# -> set SectionA.Value to 100269
# print $myCnf->set('SectionA.Value',100269)."\n"; 
#
sub set {
    my $self=shift;    
    my $name= (@_) ? shift : '';
    my $value= (@_) ? shift : '';
    if ($name ne '') {
        $self->{CNF}->{$name}=$value;
    }
    else {
        $self->{fileName}=$value;
    }
}

1;
